# = Class: composer_install
#
# The class to run composer install command in an application.
#
# === Parameters
#
# [*repo*]
#   Url of a repo with app.
#
# [*command*]
#   The command to run inside a project.
#   By default this is 'composer install'
#
#
# Assumption: this module is supposed to work with Symfony application
# that has redefinded target directory for vendor.
#
#

class composer_install (
    $repo    = 'https://github.com/pro-vagrant/songs-app-symfony.git',
    $branch  = 'master',
    $repoDir = '/tmp/repo',
    $command = 'composer install -n'
) {

    # validate_platform() function comes from
    # puppet module gajdaw/diverse_functions
    #
    #     https://forge.puppetlabs.com/gajdaw/diverse_functions
    #
    if !validate_platform($module_name) {
        fail("Platform not supported in module '${module_name}'.")
    }

    Exec { path => [
        '/usr/local/sbin',
        '/usr/local/bin',
        '/usr/sbin',
        '/usr/bin',
        '/sbin',
        '/bin'
    ]}

    vcsrepo { $repoDir:
        ensure   => 'present',
        provider => 'git',
        source   => $repo,
        user     => 'vagrant',
        group    => 'vagrant',
        depth    => 1,
        branch   => $branch
    }

    exec { 'command to install dependencies':
        command     => $command,
        cwd         => $repoDir,
        user        => 'vagrant',
        timeout     => 3000,
        environment => 'COMPOSER_HOME=/root',
        require     => [Vcsrepo[$repoDir]]
    }

    file { 'Remove composer cache':
        ensure  => absent,
        path    => '/root/cache',
        force   => true,
        require => Exec['command to install dependencies']
    }

    file { 'Remove composer cache in vagrant home':
        ensure  => absent,
        path    => '/home/vagrant/.composer',
        force   => true,
        require => Exec['command to install dependencies']
    }

    file { 'Remove cache in vagrant home':
        ensure  => absent,
        path    => '/home/vagrant/.cache',
        force   => true,
        require => Exec['command to install dependencies']
    }

    exec { 'Remove repo':
        command => "rm -rf ${repoDir}",
        require => Exec['command to install dependencies']
    }

}

